<?php

if (!defined( 'ABSPATH' )) {
	exit;
}
if (!class_exists( 'Ovadefault_Customize' )){

	class Ovadefault_Customize {

		public function __construct() {
			add_action( 'customize_register', array( $this, 'charihope_customize_register' ) );
		}

		public function charihope_customize_register($wp_customize) {

			$this->charihope_init_remove_setting( $wp_customize );
			$this->charihope_init_ova_typography( $wp_customize );
			$this->charihope_init_ova_layout( $wp_customize );
			$this->charihope_init_ova_header( $wp_customize );
			$this->charihope_init_ova_footer( $wp_customize );
			$this->charihope_init_ova_blog( $wp_customize );
			$this->charihope_init_ova_key_google_api( $wp_customize );
			$this->charihope_init_ova_archive_donation( $wp_customize );

			do_action( 'charihope_customize_register', $wp_customize );
		}

		public function charihope_init_remove_setting( $wp_customize ){
			/* Remove Colors &  Header Image Customize */
			$wp_customize->remove_section('colors');
			$wp_customize->remove_section('header_image');
		}


		/* Typo */
		public function charihope_init_ova_typography($wp_customize){




			/* Body Pane ******************************/
			$wp_customize->add_section( 'typo_general' , array(
				'title'      => esc_html__( 'Typography', 'charihope' ),
				'priority'   => 1,
			    
			) );


			/* General Typo */
			$wp_customize->add_setting( 'general_heading', array(
				'default' => '',
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );

			$wp_customize->add_control(
				new Ovadefault_Customize_Control_Heading( 
					$wp_customize, 
					'general_heading', 
					array(
						'label'          => esc_html__('General Typo','charihope'),
						'section'        => 'typo_general',
						'settings'       => 'general_heading',
					) )
			);


			/* General Font */
			$wp_customize->add_setting( 'primary_font',
				array(
					'default' => charihope_default_primary_font(),
					'sanitize_callback' => 'charihope_google_font_sanitization'
				)
			);
			$wp_customize->add_control( new Ovadefault_Google_Font_Select_Custom_Control( $wp_customize, 'primary_font',
				array(
					'label' => esc_html__( 'Primary Font', 'charihope' ),
					'section' => 'typo_general',
					'input_attrs' => array(
						'font_count' => 'all',
						'orderby' => 'popular',
					),
				)
			) );


			/* Font Size */
			$wp_customize->add_setting( 'general_font_size', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '16px',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );

			$wp_customize->add_control('general_font_size', array(
				'label' => esc_html__('Font Size','charihope'),
				'description' => esc_html__('Example: 16px, 1.2em','charihope'),
				'section' => 'typo_general',
				'settings' => 'general_font_size',
				'type' 		=>'text'
			));

			/* Line Height */
			$wp_customize->add_setting( 'general_line_height', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '25px',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );

			$wp_customize->add_control('general_line_height', array(
				'label' => esc_html__('Line height','charihope'),
				'description' => esc_html__('Example: 23px, 1.6em','charihope'),
				'section' => 'typo_general',
				'settings' => 'general_line_height',
				'type' 		=>'text'
			));


			/* Letter Space */
			$wp_customize->add_setting( 'general_letter_space', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '0px',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );

			$wp_customize->add_control('general_letter_space', array(
				'label' => esc_html__('Letter Spacing','charihope'),
				'description' => esc_html__('Example: 0px, 0.5em','charihope'),
				'section' => 'typo_general',
				'settings' => 'general_letter_space',
				'type' 		=>'text'
			));


			$wp_customize->add_setting( 'general_color', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '#666666',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 
					'general_color', 
					array(
						'label'          => esc_html__("Content Color",'charihope'),
						'section'        => 'typo_general',
						'settings'       => 'general_color',
					) ) 
			);


			/* Message */
			$wp_customize->add_setting( 'second_font_message', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control(
				new Ovadefault_Customize_Control_Heading( 
					$wp_customize, 
					'second_font_message', 
					array(
						'label'          => esc_html__('Second Font','charihope'),
						'section'        => 'typo_general',
						'settings'       => 'second_font_message',
					) )
			);

			/* Heading Font */
			$wp_customize->add_setting( 'second_font',
				array(
					'default' => charihope_default_second_font(),
					'sanitize_callback' => 'charihope_google_font_sanitization'
				)
			);
			$wp_customize->add_control( new Ovadefault_Google_Font_Select_Custom_Control( $wp_customize, 'second_font',
				array(
					'label' => esc_html__( 'Font', 'charihope' ),
					'section' => 'typo_general',
					'input_attrs' => array(
						'font_count' => 'all',
						'orderby' => 'popular',
					),
				)
			) );



			$wp_customize->add_setting( 'color_message', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );

			$wp_customize->add_control(
				new Ovadefault_Customize_Control_Heading( 
					$wp_customize, 
					'color_message', 
					array(
						'label'          => esc_html__('General Color','charihope'),
						'section'        => 'typo_general',
						'settings'       => 'color_message',
					) )
			);


			$wp_customize->add_setting( 'primary_color', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '#fa7f4b',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 
					'primary_color', 
					array(
						'label'          => esc_html__("Primary color",'charihope'),
						'section'        => 'typo_general',
						'settings'       => 'primary_color',
					) ) 
			);





			/* Custom Font */
			/* Message */
			$wp_customize->add_setting( 'custom_font_message', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control(
				new Ovadefault_Customize_Control_Heading( 
					$wp_customize, 
					'custom_font_message', 
					array(
						'label'          => esc_html__('Custom Font','charihope'),
						'section'        => 'typo_general',
						'settings'       => 'custom_font_message',
					) )
			);


			$wp_customize->add_control(
				new Ovadefault_Customize_Control_Heading( 
					$wp_customize, 
					'custom_font_message', 
					array(
						'label'          => esc_html__('Custom Font','charihope'),
						'section'        => 'typo_general',
						'settings'       => 'custom_font_message',
					) )
			);

			$wp_customize->add_setting( 'ova_custom_font', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );

			$wp_customize->add_control('ova_custom_font', array(
				'label' => esc_html__('Custom Font','charihope'),
				'description' => esc_html__('Step 1: Insert font-face in style.css file: Refer https://www.w3schools.com/cssref/css3_pr_font-face_rule.asp. Step 2: Insert font-family and font-weight like format: 
					["Perpetua", "Regular:Bold:Italic:Light"]. Step 3: Refresh customize page to display new font in dropdown font field.','charihope'),
				'section' => 'typo_general',
				'settings' => 'ova_custom_font',
				'type' =>'textarea'
			));


			

		}


		/* Layout */
		public function charihope_init_ova_layout( $wp_customize ){

			$wp_customize->add_section( 'layout_section' , array(
				'title'      => esc_html__( 'Layout', 'charihope' ),
				'priority'   => 2,
			) );


			$wp_customize->add_setting( 'global_preload', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => 'yes',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_preload', array(
				'label' => esc_html__('Preload','charihope'),
				'section' => 'layout_section',
				'settings' => 'global_preload',
				'type' =>'select',
				'choices' => array(
					'yes' => esc_html__('Yes', 'charihope'),
					'no' => esc_html__('No', 'charihope')
				)
			));

			$wp_customize->add_setting( 'global_layout', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => 'layout_2r',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_layout', array(
				'label' => esc_html__('Layout','charihope'),
				'section' => 'layout_section',
				'settings' => 'global_layout',
				'type' =>'select',
				'choices' => apply_filters( 'charihope_define_layout', '' )
			));

			$wp_customize->add_setting( 'global_sidebar_width', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => '320',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_sidebar_width', array(
				'label' => esc_html__('Sidebar Width (px)','charihope'),
				'section' => 'layout_section',
				'settings' => 'global_sidebar_width',
				'type' =>'number'
			));
			

			$wp_customize->add_setting( 'global_width_content', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => '1170',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_width_content', array(
				'label' => esc_html__('Width Content (px)','charihope'),
				'section' => 'layout_section',
				'settings' => 'global_width_content',
				'type' =>'number',
				'default' => '1170'
			));

			$wp_customize->add_setting( 'global_width_site', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => 'wide',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_width_site', array(
				'label' => esc_html__('Width Site','charihope'),
				'section' => 'layout_section',
				'settings' => 'global_width_site',
				'type' =>'select',
				'choices' => apply_filters('charihope_define_wide_boxed', '')
			));

			$wp_customize->add_setting( 'global_boxed_container_width', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => '1170',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_boxed_container_width', array(
				'label' => esc_html__('Boxed Container Width (px)','charihope'),
				'section' => 'layout_section',
				'settings' => 'global_boxed_container_width',
				'type' =>'number',
				'default' => '1170'
			));
			$wp_customize->add_setting( 'global_boxed_offset', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => '20',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_boxed_offset', array(
				'label' => esc_html__('Boxed Offset (px)','charihope'),
				'section' => 'layout_section',
				'settings' => 'global_boxed_offset',
				'type' =>'number',
				'default' => '20'
			));

		}

		/* Header */
		public function charihope_init_ova_header( $wp_customize ){

			$wp_customize->add_section( 'header_section' , array(
				'title'      => esc_html__( 'Header', 'charihope' ),
				'priority'   => 3,
			) );

			$wp_customize->add_setting( 'global_header', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => 'default',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_header', array(
				'label' => esc_html__('Header Default','charihope'),
				'description' => esc_html__('This isn\'t effect in Blog' ,'charihope'),
				'section' => 'header_section',
				'settings' => 'global_header',
				'type' =>'select',
				'choices' => apply_filters('charihope_list_header', '')
			));

		}

		/* Footer */
		public function charihope_init_ova_footer( $wp_customize ){

			$wp_customize->add_section( 'footer_section' , array(
				'title'      => esc_html__( 'Footer', 'charihope' ),
				'priority'   => 4,
			) );

			$wp_customize->add_setting( 'global_footer', array(
			  'type' => 'theme_mod', // or 'option'
			  'capability' => 'edit_theme_options',
			  'theme_supports' => '', // Rarely needed.
			  'default' => 'default',
			  'transport' => 'refresh', // or postMessage
			  'sanitize_callback' => 'sanitize_text_field' // Get function name 
			  
			) );
			$wp_customize->add_control('global_footer', array(
				'label' => esc_html__('Footer Default','charihope'),
				'description' => esc_html__('This isn\'t effect in Blog' ,'charihope'),
				'section' => 'footer_section',
				'settings' => 'global_footer',
				'type' =>'select',
				'choices' => apply_filters('charihope_list_footer', '')
			));

		}


		/* Blog */
		public function charihope_init_ova_blog( $wp_customize ){

			$wp_customize->add_panel( 'blog_panel', array(
				'title'      => esc_html__( 'Blog', 'charihope' ),
				'priority' => 5,
			) );

			$wp_customize->add_section( 'blog_section' , array(
				'title'      => esc_html__( 'Archive', 'charihope' ),
				'priority'   => 30,
				'panel' => 'blog_panel',
			) );

			$wp_customize->add_setting( 'blog_template', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => 'default',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('blog_template', array(
				'label' => esc_html__('Type','charihope'),
				'section' => 'blog_section',
				'settings' => 'blog_template',
				'type' =>'select',
				'choices' => array(
					'default' => esc_html__('Classic', 'charihope'),
					'grid' => esc_html__('Grid', 'charihope'),
				)
			));

			$wp_customize->add_setting( 'blog_layout', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => 'layout_2r',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('blog_layout', array(
				'label' => esc_html__('Layout','charihope'),
				'section' => 'blog_section',
				'settings' => 'blog_layout',
				'type' =>'select',
				'choices' => apply_filters( 'charihope_define_layout', '' )
			));

			$wp_customize->add_setting( 'blog_sidebar_width', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '320',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('blog_sidebar_width', array(
				'label' => esc_html__('Sidebar Width (px)','charihope'),
				'section' => 'blog_section',
				'settings' => 'blog_sidebar_width',
				'type' =>'number'
			));


			$wp_customize->add_setting( 'blog_num_text_grid', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '20',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('blog_num_text_grid', array(
				'label' => esc_html__('Number text blog grid','charihope'),
				'section' => 'blog_section',
				'settings' => 'blog_num_text_grid',
				'type' =>'number'
			));








			$wp_customize->add_setting( 'blog_header', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => 'default',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('blog_header', array(
				'label' => esc_html__('Header','charihope'),
				'section' => 'blog_section',
				'settings' => 'blog_header',
				'type' =>'select',
				'choices' => apply_filters('charihope_list_header', '')
			));

			$wp_customize->add_setting( 'blog_footer', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => 'default',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('blog_footer', array(
				'label' => esc_html__('Footer','charihope'),
				'section' => 'blog_section',
				'settings' => 'blog_footer',
				'type' =>'select',
				'choices' => apply_filters('charihope_list_footer', '')
			));


			$wp_customize->add_section( 'single_section' , array(
				'title'      => esc_html__( 'Single', 'charihope' ),
				'priority'   => 30,
				'panel' => 'blog_panel',
			) );	

			$wp_customize->add_setting( 'single_layout', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => 'layout_2r',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('single_layout', array(
				'label' => esc_html__('Layout','charihope'),
				'section' => 'single_section',
				'settings' => 'single_layout',
				'type' =>'select',
				'choices' => apply_filters( 'charihope_define_layout', '' )
			));

			$wp_customize->add_setting( 'single_sidebar_width', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => '300',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('single_sidebar_width', array(
				'label' => esc_html__('Sidebar Width (px)','charihope'),
				'section' => 'single_section',
				'settings' => 'single_sidebar_width',
				'type' =>'number'

			));


			$wp_customize->add_setting( 'show_hide_date_single', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => 'no',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('show_hide_date_single', array(
				'label' => esc_html__('Show hide date single','charihope'),
				'section' => 'single_section',
				'settings' => 'show_hide_date_single',
				'type' =>'select',
				'choices' => array(
					'yes' => esc_html__('Yes', 'charihope'),
					'no' => esc_html__('No', 'charihope')
				)
			));




			$wp_customize->add_setting( 'single_header', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => 'default',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('single_header', array(
				'label' => esc_html__('Header','charihope'),
				'section' => 'single_section',
				'settings' => 'single_header',
				'type' =>'select',
				'choices' => apply_filters('charihope_list_header', '')
			));

			$wp_customize->add_setting( 'single_footer', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'default' => 'default',
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );
			$wp_customize->add_control('single_footer', array(
				'label' => esc_html__('Footer','charihope'),
				'section' => 'single_section',
				'settings' => 'single_footer',
				'type' =>'select',
				'choices' => apply_filters('charihope_list_footer', '')
			));

		}

		

		public function charihope_init_ova_key_google_api ($wp_customize) {
			$wp_customize->add_section( 'key_google' , array(
				'title'      => esc_html__( 'Key Google Api', 'charihope' ),
				'priority'   => 10,
			) );

			$wp_customize->add_setting( 'key_google_api', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field' // Get function name 
				  
				) );

			$wp_customize->add_control('key_google_api', array(
				'label' => esc_html__('Key google api','charihope'),
				'section' => 'key_google',
				'settings' => 'key_google_api',
				'type' 		=>'text'
			));
		}

		public function charihope_init_ova_archive_donation ($wp_customize) {
			$wp_customize->add_section( 'archive_donation' , array(
				'title'      => esc_html__( 'Archive Donation', 'charihope' ),
				'priority'   => 10,
			) );

			$wp_customize->add_setting( 'archive_donation_show_sidebar', array(
				  'type' => 'theme_mod', // or 'option'
				  'capability' => 'edit_theme_options',
				  'theme_supports' => '', // Rarely needed.
				  'transport' => 'refresh', // or postMessage
				  'sanitize_callback' => 'sanitize_text_field', // Get function name 
				  'default'  => '',
				) );

			$wp_customize->add_control('archive_donation_show_sidebar', array(
				'label'    => esc_html__('Show Sidebar','charihope'),
				'section'  => 'archive_donation',
				'settings' => 'archive_donation_show_sidebar',
				'type'     => 'select',
				'choices'  => array(
					'' => esc_html__('Yes', 'charihope'),
					'type_2' => esc_html__('No', 'charihope')
				)
			));
		}
	}
}

new Ovadefault_Customize();






