<?php 

if( !defined( 'ABSPATH' ) ) exit();


if( !class_exists( 'OVAEM_Admin_Settings' ) ){

	/**
	 * Make Admin Class
	 */
	class OVAEM_Admin_Settings{

		/**
		 * Construct Admin
		 */
		public function __construct(){
			add_action( 'admin_enqueue_scripts', array( $this, 'ovaem_load_media' ) );
			add_action( 'admin_init', array( $this, 'register_options' ) );
		}

		public function ovaem_load_media() {
			wp_enqueue_media();
		}

		public function print_options_section(){
			return true;
		}

		public function register_options(){

			register_setting(
				'ovaem_options_group', // Option group
				'ovaem_options', // Name Option
				array( $this, 'settings_callback' ) // Call Back
			);

			/**
			 * General Settings
			 */
			// Add Section: General Settings
			add_settings_section(
				'ovaem_general_section_id', // ID
				esc_html__('General Setting', 'ova-events-manager'), // Title
				array( $this, 'print_options_section' ),
				'ovaem_general_settings' // Page
			);

			// Add Fields: General Section
			add_settings_field(
				'ovaem_event_post_type_rewrite_slug', // ID
				esc_html__('Rewrite Slug','ova-events-manager'),
				array( $this, 'ovaem_event_post_type_rewrite_slug' ),
				'ovaem_general_settings', // Page
				'ovaem_general_section_id' // Section ID
			);
			add_settings_field(
				'ovaem_admin_format_date', // ID
				esc_html__('Calendar Date Format','ova-events-manager'),
				array( $this, 'ovaem_admin_format_date' ),
				'ovaem_general_settings', // Page
				'ovaem_general_section_id' // Section ID
			);
			add_settings_field(
				'ovaem_admin_format_time', // ID
				esc_html__('Calendar Time Format','ova-events-manager'),
				array( $this, 'ovaem_admin_format_time' ),
				'ovaem_general_settings', // Page
				'ovaem_general_section_id' // Section ID
			);
			add_settings_field(
				'ovaem_admin_format_date_lang', // ID
				esc_html__('Calendar Language','ova-events-manager'),
				array( $this, 'ovaem_admin_format_date_lang' ),
				'ovaem_general_settings', // Page
				'ovaem_general_section_id' // Section ID
			);

			/**
			 * Basic Settings
			 */

			/** Add Section: Archive Event Settings **/
			add_settings_section(
				'ovaem_archive_event_section_id', // ID
				esc_html__('Archive Event Setting', 'ova-events-manager'), // Title
				array( $this, 'print_options_section' ),
				'ovaem_archive_event_settings' // Page
			);

			add_settings_field(
				'archive_event_type', // ID
				esc_html__('Archive Event Type','ova-events-manager'),
				array( $this, 'archive_event_type' ),
				'ovaem_archive_event_settings', // Page
				'ovaem_archive_event_section_id' // Section ID
			);

			add_settings_field(
				'archive_event_order', // ID
				esc_html__('Order','ova-events-manager'),
				array( $this, 'archive_event_order' ),
				'ovaem_archive_event_settings', // Page
				'ovaem_archive_event_section_id' // Section ID
			);

			add_settings_field(
				'archive_event_orderby', // ID
				esc_html__('Order By','ova-events-manager'),
				array( $this, 'archive_event_orderby' ),
				'ovaem_archive_event_settings', // Page
				'ovaem_archive_event_section_id' // Section ID
			);

		}

		public function settings_callback( $input ){

			$new_input = array();

			if( isset( $input['ovaem_event_post_type_rewrite_slug'] ) )
				$new_input['ovaem_event_post_type_rewrite_slug'] = sanitize_text_field( $input['ovaem_event_post_type_rewrite_slug'] ) ? sanitize_text_field( $input['ovaem_event_post_type_rewrite_slug'] ) : 'event';

			if( isset( $input['archive_event_orderby'] ) )
				$new_input['archive_event_orderby'] = sanitize_text_field( $input['archive_event_orderby'] ) ? sanitize_text_field( $input['archive_event_orderby'] ) : 'title';

			if( isset( $input['archive_event_order'] ) )
				$new_input['archive_event_order'] = sanitize_text_field( $input['archive_event_order'] ) ? sanitize_text_field( $input['archive_event_order'] ) : 'ASC';
			
			if( isset( $input['ovaem_admin_format_date'] ) )
				$new_input['ovaem_admin_format_date'] = sanitize_text_field( $input['ovaem_admin_format_date'] ) ? sanitize_text_field( $input['ovaem_admin_format_date'] ) : 'Y/m/d';
			
			if( isset( $input['ovaem_admin_format_time'] ) )
				$new_input['ovaem_admin_format_time'] = sanitize_text_field( $input['ovaem_admin_format_time'] ) ? sanitize_text_field( $input['ovaem_admin_format_time'] ) : 'H:i';

			if( isset( $input['archive_event_type'] ) )
				$new_input['archive_event_type'] = sanitize_text_field( $input['archive_event_type'] ) ? sanitize_text_field( $input['archive_event_type'] ) : 'classic';
			
			if( isset( $input['ovaem_admin_format_date_lang'] ) )
				$new_input['ovaem_admin_format_date_lang'] = sanitize_text_field( $input['ovaem_admin_format_date_lang'] ) ? sanitize_text_field( $input['ovaem_admin_format_date_lang'] ) : 'en';

			return $new_input;
		}

		public static function create_admin_setting_page() { ?>
			<div class="wrap">
				<h1><?php esc_html_e( "Event Settings", 'ova-events-manager' ); ?></h1>

				<form method="post" action="options.php">

					<div id="tabs">

						<?php settings_fields( 'ovaem_options_group' ); // Options group ?>

						<!-- Menu Tab -->
						<ul>
							<li><a href="#ovaem_general_settings"><?php esc_html_e( 'General Settings', 'ova-events-manager' ); ?></a></li>
							<li><a href="#ovaem_event_settings"><?php esc_html_e( 'Event Settings', 'ova-events-manager' ); ?></a></li>
						</ul>

						<!-- General Settings -->  
						<div id="ovaem_general_settings" class="ovaem_admin_settings">
							<?php do_settings_sections( 'ovaem_general_settings' ); // Page ?>
						</div>

						<!-- Event Settings -->  
						<div id="ovaem_event_settings" class="ovaem_admin_settings">
							<?php do_settings_sections( 'ovaem_archive_event_settings' ); // Archive ?>
						</div>

					</div>

					<?php submit_button(); ?>
				</form>
			</div>

		<?php }


		/***** General Settings *****/
		public function ovaem_event_post_type_rewrite_slug(){
			$ovaem_event_post_type_rewrite_slug = esc_attr( OVAEM_Settings::ovaem_event_post_type_rewrite_slug() );
			printf(
				'<input type="text"  id="ovaem_event_post_type_rewrite_slug" name="ovaem_options[ovaem_event_post_type_rewrite_slug]" value="%s" />',
				isset( $ovaem_event_post_type_rewrite_slug ) ? $ovaem_event_post_type_rewrite_slug : 'event'
			);
			echo '<span >'.esc_html__(' Name should only contain lowercase letters and the underscore character, and not be more than 32 characters long and  without any spaces', 'ova-events-manager').'<span>';
		}

		public function ovaem_admin_format_date(){
			$ovaem_admin_format_date = OVAEM_Settings::ovaem_admin_format_date() ? OVAEM_Settings::ovaem_admin_format_date() : 'Y/m/d';
			?>
			<input type="text" name="ovaem_options[ovaem_admin_format_date]" value="<?php echo esc_attr($ovaem_admin_format_date) ?>" />
			<?php
			echo esc_html__('Example: Y/m/d','ova-events-manager');
			echo '<br/>'.esc_html__('You can find format','ova-events-manager').' <a href="http://php.net/manual/en/function.date.php" target="_blank">'.'Here'.'</a>';
		}

		public function ovaem_admin_format_time(){
			$ovaem_admin_format_time = OVAEM_Settings::ovaem_admin_format_time() ? OVAEM_Settings::ovaem_admin_format_time() : 'H:i';
			?>
			<input type="text" name="ovaem_options[ovaem_admin_format_time]" value="<?php echo esc_attr($ovaem_admin_format_time) ?>" />
			<?php
			echo esc_html__('Example: H:i','ova-events-manager');
			echo '<br/>'.esc_html__('You can find format','ova-events-manager').' <a href="http://php.net/manual/en/function.date.php" target="_blank">'.'Here'.'</a>';
		}

		public function ovaem_admin_format_date_lang(){
			$ovaem_admin_format_date_lang = OVAEM_Settings::ovaem_admin_format_date_lang() ? OVAEM_Settings::ovaem_admin_format_date_lang() : 'en';
			?>
			<input type="text" name="ovaem_options[ovaem_admin_format_date_lang]" value="<?php echo esc_attr($ovaem_admin_format_date_lang) ?>" />
			<?php
			echo esc_html__('Example: en','ova-events-manager');
			echo '<br/>'.esc_html__('You can check language here','ova-events-manager').' <a href="https://xdsoft.net/jqplugins/datetimepicker/#lang" target="_blank">'.'Here'.'</a>';
		}



		/***** Archive Event Settings *****/

		public function archive_event_type(){
			$archive_event_type = OVAEM_Settings::archive_event_type(); 	
			$archive_event_type = isset( $archive_event_type ) ? $archive_event_type : 'classic';

			$classic = ('classic' == $archive_event_type) ? 'selected' : '';
			$grid = ('grid' == $archive_event_type) ? 'selected' : '';

			?>
			<select name="ovaem_options[archive_event_type]" id="archive_event_type">
				<option <?php echo esc_attr($classic) ?> value="classic"><?php echo esc_html__('Classic', 'ova-events-manager') ?></option>
				<option <?php echo esc_attr($grid) ?> value="grid"><?php echo esc_html__('Grid', 'ova-events-manager') ?></option>
			</select>
			<?php
		}

		public function archive_event_orderby(){
			$archive_event_orderby = OVAEM_Settings::archive_event_orderby();
			$archive_event_orderby = isset( $archive_event_orderby ) ? $archive_event_orderby : 'title';

			$title             = ( 'title' == $archive_event_orderby) ? 'selected' : '';
			$ovaem_start_date  = ( 'ovaem_start_date' == $archive_event_orderby) ? 'selected' : '';
			$id                = ( 'ID' == $archive_event_orderby) ? 'selected' : '';

			?>
			<select name="ovaem_options[archive_event_orderby]" id="archive_event_orderby">
				<option <?php echo esc_attr($title) ?> value="title"><?php echo esc_html__('Title', 'ova-events-manager') ?></option>
				<option <?php echo esc_attr($ovaem_start_date) ?> value="ovaem_start_date"><?php echo esc_html__('Start Date', 'ova-events-manager') ?></option>
				<option <?php echo esc_attr($id) ?> value="ID"><?php echo esc_html__('ID', 'ova-events-manager') ?></option>
			</select>
			<?php
		}

		public function archive_event_order(){
			$archive_event_order = OVAEM_Settings::archive_event_order(); 	
			$archive_event_order = isset( $archive_event_order ) ? $archive_event_order : 'ASC';

			$asc_selected  = ('ASC' == $archive_event_order) ? 'selected' : '';
			$desc_selected = ('DESC' == $archive_event_order) ? 'selected' : '';

			?>
			<select name="ovaem_options[archive_event_order]" id="archive_event_order">
				<option <?php echo esc_attr($asc_selected) ?> value="ASC"><?php echo esc_html__('Increase', 'ova-events-manager') ?></option>
				<option <?php echo esc_attr($desc_selected) ?> value="DESC"><?php echo esc_html__('Decrease', 'ova-events-manager') ?></option>
			</select>
			<?php
		}

		/*****  Single Event Settings *****/


	}
	new OVAEM_Admin_Settings();
}