<?php
namespace ovapo_elementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_events_manager_element extends Widget_Base {

	public function get_name() {
		return 'ova_events_manager_element';
	}

	public function get_title() {
		return __( 'Ova Even Manager', 'ova-events-manager' );
	}

	public function get_icon() {
		return 'eicon-posts-grid';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {		

		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		$args = array(
			'taxonomy' => 'event_cat',
			'orderby' => 'name',
			'order'   => 'ASC'
		);

		$categories = get_categories($args);
		$catAll = array( 'all' => 'All categories');
		$cate_array = array();
		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->cat_name] = $cate->slug;
			}
		} else {
			$cate_array["No content Category found"] = 0;
		}


		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'ova-events-manager' ),
			]
		);

		$this->add_control(
			'category',
			[
				'label'   => __( 'Choose Category', 'ova-events-manager' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => array_merge( $catAll, $cate_array )
			]
		);

		$this->add_control(
			'order',
			[
				'label'   => __( 'Order', 'ova-events-manager' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'ASC'  => __( 'Increase', 'ova-events-manager' ),
					'DESC' => __( 'Decrease', 'ova-events-manager' ),
				],
			]
		);

		$this->add_control(
			'show_views_all',
			[
				'label'        => __( 'Show View All', 'plugin-domain' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'ova-events-manager' ),
				'label_off'    => __( 'Hide', 'ova-events-manager' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'post_left_style',
			[
				'label' => __( 'Post Left', 'ova-events-manager' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .wrapp-element .event-post-left .inner .event-content .event-info h3',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label'      => __( 'Padding', 'ova-events-manager' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .wrapp-element .event-post-left .inner .event-content .event-info h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => __( 'Color', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .event-post-left .inner .event-content .event-info h3 a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'title_color_hover',
			[
				'label'     => __( 'Color Hover', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .event-post-left .inner .event-content .event-info h3 a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'bgr_overlay',
			[
				'label'     => __('Background Overlay','ova-events-manager'),
				'type'      => Controls_Manager::COLOR,
				'default'   => 'rgba(250, 127, 75, 0.86)',
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .event-post-left .inner .event-content' => 'background-color: {{VALUE}};'
				]
			]
		);

		/* Settings Post Right */

		$this->end_controls_section();

		$this->start_controls_section(
			'post_right_style',
			[
				'label' => __( 'Post Right', 'ova-events-manager' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'post_right_typography',
				'selector' => '{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .event-info h3',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'post_right_title_padding',
			[
				'label'      => __( 'Padding', 'ova-events-manager' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .event-info h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'post_right_title_color',
			[
				'label'     => __( 'Color', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .event-info h3 a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'post_right_title_color_hover',
			[
				'label'     => __( 'Color Hover', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .event-info h3 a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'date_address',
			[
				'label'     => __( 'Date - Address', 'ova-events-manager' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'date_address_typography',
				'selector' => '{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .event-info span',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'date_address_padding',
			[
				'label'      => __( 'Padding', 'ova-events-manager' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .event-info span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'date_address_color',
			[
				'label'     => __( 'Color', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .event-info span' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'read_more',
			[
				'label'     => __( 'Read More', 'ova-events-manager' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'read_more_typography',
				'selector' => '{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .btn-link',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'read_more_padding',
			[
				'label'      => __( 'Padding', 'ova-events-manager' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .btn-link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'read_more_color',
			[
				'label'     => __( 'Color', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .btn-link' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'read_more_color_hover',
			[
				'label'     => __( 'Color Hover', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .event-post-right .inner .list_items .event-content .btn-link:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		/* Button */

		$this->start_controls_section(
			'button_views_all',
			[
				'label' => __( 'Button Views All', 'ova-events-manager' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'selector' => '{{WRAPPER}} .wrapp-element .view-all .btn-link-views',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'button_padding',
			[
				'label'      => __( 'Padding', 'ova-events-manager' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .wrapp-element .view-all .btn-link-views' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'button_margin',
			[
				'label'      => __( 'Margin', 'ova-events-manager' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .wrapp-element .view-all' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'button_color',
			[
				'label'     => __( 'Color', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .view-all .btn-link-views' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'button_color_hover',
			[
				'label'     => __( 'Color Hover', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .view-all .btn-link-views:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label'     => __( 'Background Color', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .view-all .btn-link-views' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'button_background_color_hover',
			[
				'label'     => __( 'Background Color Hover', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .view-all .btn-link-views:hover' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'        => 'border',
				'placeholder' => '1px',
				'default'     => '1px',
				'selector'    => '{{WRAPPER}} .wrapp-element .view-all .btn-link-views',
				'separator'   => 'before',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label'      => __( 'Border Radius', 'ova-events-manager' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .wrapp-element .view-all .btn-link-views' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'button_color_hover_border',
			[
				'label'     => __( 'Border Color Hover', 'ova-events-manager' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapp-element .view-all .btn-link-views:hover' => 'border-color: {{VALUE}}',
				],
			]
		);

	}

	protected function render() {

		$settings = $this->get_settings();

		if( $settings['category'] === 'all'){

			$args= array(
				'post_type'      => 'event',
				'post_status'    => 'publish',
				'posts_per_page' => 3,
				'order'          => $settings['order'],
			);

		} elseif( $settings['category'] != 'all' ) {

			$args= array(
				'post_type'      => 'event',
				'post_status'    => 'publish',
				'posts_per_page' => 3,
				'tax_query'      => array(
					array(
						'taxonomy' => 'event_cat',
						'field'    => 'slug',
						'terms'    => $settings['category'],
					)
				),
				'order'          => $settings['order'],
			);

		}

		$event_query  = new \WP_Query($args);

		?>
		<div class="event-element">
			<div class="wrapp-element">

				<?php 
				$item = 1;
				if( $event_query->have_posts() ) : while( $event_query->have_posts() ) : $event_query->the_post();

					$img_src    = wp_get_attachment_image_url( get_post_thumbnail_id(), 'large' );
					$img_srcset = wp_get_attachment_image_srcset( get_post_thumbnail_id(), 'medium' );

					$post_ID = get_the_ID();

					$ev_start_date = get_post_meta( $post_ID, 'ovaem_start_date', true );
					$ev_location   = get_post_meta( $post_ID, 'ovaem_address', true );

					$date_start_format    = $ev_start_date != '' ? date_i18n(get_option('date_format'), $ev_start_date ) : '';


					if( $item == 1 ){ ?>
						<div class="event-post-left">
							<div class="inner" style="background: url(<?php echo esc_url($img_src);?>);">
								<a href="<?php the_permalink();?>" title="<?php the_title();?>" class="event-media"></a>
								<div class="event-content">
									<div class="event-info">
										<h3 class="second_font"><a href="<?php the_permalink();?>" title="<?php the_title();?>"><?php the_title();?></a></h3>
										<span><?php echo esc_html($date_start_format);?> - <?php echo esc_html($ev_location);?></span>
									</div>
								</div>
							</div>
						</div>		
						<div class="event-post-right">
							<div class="inner">
							<?php } else{ ?>
								<div class="list_items">
									<a href="<?php the_permalink();?>" title="<?php the_title();?>" class="event-media" style="background: url(<?php echo esc_url($img_src);?>);"></a>
									<div class="event-content">
										<div class="event-info">
											<h3 class="second_font"><a href="<?php the_permalink();?>" title="<?php the_title();?>"><?php the_title();?></a></h3>
											<span><?php echo esc_html($date_start_format);?> - <?php echo esc_html($ev_location);?></span>
											<a href="<?php the_permalink();?>" class="second_font btn-link"><?php esc_html_e('Read More','ova-events-manager');?></a>
										</div>
									</div>
								</div>
							<?php } ?>

							<?php $item++; endwhile; endif; wp_reset_postdata(); ?>

						</div>
					</div>
					<?php if( $settings['show_views_all'] === 'yes' ) : ?>
					<div class="view-all">
						<a href="<?php echo esc_url(get_post_type_archive_link( 'event' )); ?>" class="second_font btn-link-views"><?php esc_html_e('View All', 'ova-events-manager');?></a>
					</div>
					<?php endif; ?>
				</div>
			</div>
			<?php
		}
	}
