<?php

namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_about_info extends Widget_Base {

	public function get_name() {
		return 'ova_about_info';
	}

	public function get_title() {
		return __( 'About Info', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-info-box';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {


		/**********************************************
		CONTENT SECTION
		**********************************************/
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'ova-framework' ),
			]
		);

		$this->add_control(
			'info_version',
			[
				'label'   => __('Version','ova-framework'),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'info_ver1' => __('Version 1','ova-framework'),
					'info_ver2' => __('Version 2','ova-framework')
				],
				'default' => 'info_ver1'
			]
		);

		$this->add_control(
			'content',
			[
				'label' => __( 'Name', 'ova-framework' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __('“Sit amet risus nullam eget felis eget nunc. Et ligula ullamcor malesuada proin libero nunc consequat interdum. Tortor aliquam nulla facilisi cras fermentum diam sollicitudin tempor. Feugiat in fermentum posuer urna nec tincidunt praesent semper. Molestie nunc non blandit massa enim nec dui. Lectus arcu bibendum at varius vel pharetra vel turpis nunc. Commodo sed egestas egestas fringilla phasellus.', 'ova-framework'),
			]
		);

		$this->add_control(
			'image_info',
			[
				'label' => __( 'Image', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'info_version',
							'value' => 'info_ver1',
						],
					],
				]
			]
		);

		$this->add_control(
			'name_info',
			[
				'label' => __( 'Name', 'ova-framework' ),
				'type' => Controls_Manager::TEXTAREA,
				'row' => 2,
				'default' => __("Jeremy Murphy", "ova-framework"),
			]
		);

		$this->add_control(
			'job_info',
			[
				'label' => __( 'Job', 'ova-framework' ),
				'type' => Controls_Manager::TEXTAREA,
				'row' => 2,
				'default' => __("CEO & Founder ChariHope ", "ova-framework"),
			]
		);

		$this->add_control(
			'image_info_signature',
			[
				'label' => __( 'Signature', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'info_version',
							'value' => 'info_ver1',
						],
					],
				]
			]
		);


		$this->end_controls_section();


		//section style title
		$this->start_controls_section(
			'content_style',
			[
				'label' => __( 'Content', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} .ova-about-info .ova-content p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_content',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-about-info .ova-content p' => 'color : {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'padding_content',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-about-info .ova-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style sub title
		$this->start_controls_section(
			'name_style',
			[
				'label' => __( 'Name', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'name_info_typography',
				'selector' => '{{WRAPPER}} .ova-about-info .ova-info .infomation .client h4',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_name_style',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-about-info .ova-info .infomation .client h4' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'padding_name_info',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-about-info .ova-info .infomation .client h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style Job

		$this->start_controls_section(
			'job_style',
			[
				'label' => __( 'Job', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'job_info_typography',
				'selector' => '{{WRAPPER}} .ova-about-info .ova-info .infomation .client span',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_job_style',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-about-info .ova-info .infomation .client span' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'padding_job_info',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-about-info .ova-info .infomation .client span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'quote_style',
			[
				'label' => __( 'Quote', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'quote_color',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-about-info .ova-content:before' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'quote_size',
			[
				'label' => __( 'Font Size', 'ova-framework' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 50,
				],
				'selectors' => [
					'{{WRAPPER}} .ova-about-info .ova-content:before' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();


	}

	protected function render() {
		$settings = $this->get_settings();

		$content = $settings['content'];
		$job_info  = $settings['image_info'];
		$tabs = $settings['job_info'];

		?>
		<div class="ova-about-info">
			<div class="ova-content <?php echo esc_attr($settings['info_version']); ?>">
				<?php if( $content != '' ){ ?> 
					<p><?php echo esc_html($content);?></p>
				<?php } ?>
			</div>
			<div class="ova-info <?php echo esc_attr($settings['info_version']); ?>">
				<div class="infomation">
					<?php if( $settings['info_version'] === 'info_ver1') : ?>
						<div class="avatar">
							<?php if( $settings['image_info']['url'] != '' ) : ?>
								<img src="<?php echo esc_attr($settings['image_info']['url']) ?>" alt="<?php echo $settings['name_info'];?>">
							<?php endif;?>
						</div>
					<?php endif;?>
					<div class="client">
						<h4 class="second_font"><?php echo $settings['name_info'];?></h4>
						<span><?php echo $settings['job_info'];?></span>
					</div>
				</div>
				<?php if( $settings['info_version'] === 'info_ver1') : ?>
					<div class="signature">
						<?php if( $settings['image_info_signature']['url'] != '' ) : ?>
							<img src="<?php echo esc_attr($settings['image_info_signature']['url']) ?>" alt="<?php echo $settings['name_info'];?>">
						<?php endif;?>
					</div>
				<?php endif;?>
			</div>
		</div>
		<?php
	}
// end render
}


