<?php

namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_heading extends Widget_Base {

	public function get_name() {
		return 'ova_heading';
	}

	public function get_title() {
		return __( 'Ova Heading', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-heading';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_heading_content',
			[
				'label' => __( 'Content', 'ova-framework' ),
			]
		);

		$this->add_control(
			'version',
			[
				'label' => __('Version','ova-framework'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'version_1' => __('Version 1', 'ova-framework'),
					'version_2' => __('Version 2', 'ova-framework'),
				],
				'default' => 'version_1'
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => __( 'Alignment', 'ova-framework' ),
				'type'    => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'ova-framework' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'ova-framework' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'ova-framework' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'default'   => 'center',
				'selectors' => [
					'{{WRAPPER}} .ova-heading' => 'text-align: {{VALUE}}',
				]
			]
		);

		$this->add_control(
			'show_label_title',
			[
				'label'        => __( 'Show Label Title', 'plugin-domain' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'ova-framework' ),
				'label_off'    => __( 'Hide', 'ova-framework' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'version',
							'value' => 'version_2',
						],
					],
				]
			]
		);

		$this->add_control(
			'label_title',
			[
				'label'      => __('Label Title','ova-framework'),
				'type'       => Controls_Manager::TEXT,
				'default'    => __('About Us','ova-framework'),
				'conditions' => [
					'terms'  => [
						[
							'name'  => 'show_label_title',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'heading_title',
			[
				'label'     => __( 'Heading Title', 'ova-framework' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);


		$this->add_control(
			'title',
			[
				'label'   => __( 'Title', 'ova-framework' ),
				'type'    => Controls_Manager::TEXTAREA,
				'row'     => 3,
				'default' => __('Latest News', 'ova-framework'),
			]
		);

		$this->add_control(
			'html_tag_title',
			[
				'label' => __( 'HTML Tag Title', 'ova-framework' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h3',
				'options' => [
					'h1' => "H1",
					'h2' => "H2",
					'h3' => "H3",
					'h4' => "H4",
					'h5' => "H5",
					'h6' => "H6",
					'div' => "div",
					'span' => "Span",
					'p' => "p",
				]
			]
		);

		$this->add_control(
			'heading_content',
			[
				'label'     => __( 'Heading Content', 'ova-framework' ),
				'type'      => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'version',
							'value' => 'version_1',
						],
					],
				]
			]
		);

		$this->add_control(
			'content',
			[
				'label' => __( 'Content', 'ova-framework' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __("Condimentum id venenatis a condimentum vitae. Sit amet venenatis urna cursus eget nunc.", "ova-framework"),
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'version',
							'value' => 'version_1',
						],
					],
				]
			]
		);

		$this->end_controls_section();

		//section style label title
		$this->start_controls_section(
			'section_title_label',
			[
				'label' => __( 'Label Title', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'version',
							'value' => 'version_2',
						],
					],
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'label_title_typography',
				'selector' => '{{WRAPPER}} .ova-heading.version_2 span.label',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'version',
							'value' => 'version_2',
						],
					],
				]
			]
		);

		$this->add_control(
			'color_label_title',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-heading.version_2 span.label' => 'color : {{VALUE}};',
				],
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'version',
							'value' => 'version_2',
						],
					],
				]
			]
		);

		$this->add_responsive_control(
			'margin_label_title',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-heading.version_2 span.label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'version',
							'value' => 'version_2',
						],
					],
				]
			]
		);

		$this->end_controls_section();


		//section style title
		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Title', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .ova-heading .heading-title',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_title',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-heading .heading-title' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_title',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-heading .heading-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();


		//style content
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} .ova-heading .content p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_content',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-heading .content' => 'color : {{VALUE}};',
					'{{WRAPPER}} .ova-heading .content p' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_content',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-heading .content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();


	}

	protected function render() {
		$settings = $this->get_settings();

		$title     = $settings['title'];
		$content   = $settings['content'];

		$html_tag_title = $settings['html_tag_title'] !== "" ?  $settings['html_tag_title'] : "h3";

		?>
		<div class="ova-heading <?php esc_attr_e( $settings['version'] );?>">
			<?php if( $settings['show_label_title'] === 'yes' && $settings['label_title'] != '' && $settings['version'] == 'version_2') : ?>
				<span class="label"><?php echo $settings['label_title'];?></span>
			<?php endif; ?>
			<?php if (!empty($title)) : ?>
				<<?php echo $html_tag_title ?> class="heading-title second_font"><?php echo esc_html($title) ?></<?php echo $html_tag_title ?>>
			<?php endif ?>
			<?php if ( !empty($content) && $settings['version'] === 'version_1') : ?>
				<div class="content">
					<?php echo $content ?>
				</div>
			<?php endif ?>
		</div>
		<?php

	}
	// end render
}


