<?php

namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;
use Elementor\Utils;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_volunteer extends Widget_Base {

	public function get_name() {
		return 'ova_volunteer';
	}

	public function get_title() {
		return __( 'Volunteer', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-person';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {


		/**********************************************
		CONTENT SECTION
		**********************************************/
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'ova-framework' ),
			]
		);

		$this->add_control(
			'show_popup',
			[
				'label'        => __( 'Using Popup', 'plugin-domain' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'ova-framework' ),
				'label_off'    => __( 'Hide', 'ova-framework' ),
				'return_value' => 'yes',
				'default'      => 'no',
			]
		);


		$this->add_control(
			'name',
			[
				'label' => __( 'Name', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Gabriel Watkins', 'ova-framework'),
			]
		);

		$this->add_control(
			'job',
			[
				'label' => __( 'Job', 'ova-framework' ),
				'type' => Controls_Manager::TEXTAREA,
				'row' => 2,
				'default' => __("Volunteers", "ova-framework"),
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Image Thumbnail', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				]

			]
		);

		$this->add_control(
			'link_about',
			[
				'label' => __( 'Link', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'ova-framework' ),
				'default' => [
					'url' => '#',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);


		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'icon',
			[
				'label' => __( 'Description Strong', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 2,
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __( 'Link', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'ova-framework' ),
				'default' => [
					'url' => '#',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => __( 'Tabs', 'ova-framework' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'icon' => __('fa fa-facebook', 'ova-framework'),
					],
					[
						'icon' => __('fa fa-twitter', 'ova-framework'),
					],
					[
						'icon' => __('fa fa-tumblr', 'ova-framework'),
					],
					[
						'icon' => __('fa fa-pinterest-p', 'ova-framework'),
					],
					
				],
				'title_field' => '{{{ icon }}}',
			]
		);

		$this->add_control(
			'image_popup',
			[
				'label' => __( 'Image Popup', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'name_popup',
			[
				'label' => __( 'Name Popup', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Gabriel Watkins', 'ova-framework'),
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'job_popup',
			[
				'label' => __( 'Job Popup', 'ova-framework' ),
				'type' => Controls_Manager::TEXTAREA,
				'row' => 2,
				'default' => __("Volunteers", "ova-framework"),
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'content_popup',
			[
				'label' => __( 'Content Popup', 'ova-framework' ),
				'type' => Controls_Manager::TEXTAREA,
				'row' => 2,
				'default' => __("Augue ut lectus arcu bibendum at varius vel pharetra vel. Vestibulum lorem sed risus ultricies. In curs turpis massa tincidunt dui ut ornare.", "ova-framework"),
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);


		$this->end_controls_section();


		//section style title
		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Name', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .ova-volunteer .ova-content .name',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_title',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-content .name a' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_hover_title',
			[
				'label' => __( 'Color Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-content .name a:hover' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'padding_title',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-content .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style sub title
		$this->start_controls_section(
			'section_sub_title',
			[
				'label' => __( 'Job', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sub_title_typography',
				'selector' => '{{WRAPPER}} .ova-volunteer .ova-content .job',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_sub_title',
			[
				'label' => __( 'Color Sub Title', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-content .job' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_sub_title',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-heading .sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style image
		$this->start_controls_section(
			'section_image',
			[
				'label' => __( 'Image', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'margin_image',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-media' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		// Social 

		$this->start_controls_section(
			'section_social',
			[
				'label' => __( 'Social', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'social_size',
			[
				'label' => __( 'Size', 'ova-framework' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 18,
				],
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-media .list-con ul li a i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'social_spacing',
			[
				'label' => __( 'Size', 'ova-framework' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 22,
				],
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-media .list-con ul li:not(:last-child)' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'color_social',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-media .list-con ul li a i' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_hover_social',
			[
				'label' => __( 'Color Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .ova-media .list-con ul li a:hover i' => 'color : {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		/* Popup Style*/

		/* Name */

		$this->start_controls_section(
			'section_title_popup',
			[
				'label' => __( 'Name Popup', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_popup_typography',
				'selector' => '{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content h3',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'color_title_popup',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content h3' => 'color : {{VALUE}};',
				],
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);


		$this->add_responsive_control(
			'padding_title_popup',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		/* Job */

		$this->start_controls_section(
			'section_job_popup',
			[
				'label' => __( 'Job Popup', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'job_popup_typography',
				'selector' => '{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content span.job',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'color_job_popup',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content span.job' => 'color : {{VALUE}};',
				],
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);


		$this->add_responsive_control(
			'padding_job_popup',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content span.job' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		/* Content */

		$this->start_controls_section(
			'section_content_popup',
			[
				'label' => __( 'Content Popup', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_popup_typography',
				'selector' => '{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'color_content_popup',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content p' => 'color : {{VALUE}};',
				],
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_responsive_control(
			'padding_content_popup',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-volunteer .popup_volunteer .content_popup .volunteer-popup-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

		$name = $settings['name'];
		$job  = $settings['job'];
		$tabs = $settings['tabs'];

		$pop_class = '';

		if( $settings['show_popup'] === 'yes' ){
			$pop_class = 'pop-media';
		}

		?>
		<div class="ova-volunteer">
			<div class="ova-media <?php echo esc_attr( $pop_class );?>">
				<img src="<?php echo esc_attr($settings['image']['url']) ?>" alt="<?php echo esc_attr($name) ?>">
				<?php if( $settings['show_popup'] != 'yes' ) : ?>
					<div class="list-con">
						<ul>
							<?php if (!empty($tabs)) : foreach($tabs as $item) : ?>
								<li><a target="_blank" href="<?php echo esc_attr($item['link']['url']) ?>"><i class="<?php echo esc_attr($item['icon']) ?>"></i></a></li>
							<?php endforeach; endif; ?>
						</ul>
					</div>
				<?php endif; ?>
			</div>
			<div class="ova-content">
				<?php if ($name !== "") : ?>
					<h3 class="name second_font"><a href="<?php echo esc_attr($settings['link_about']['url']) ?>"><?php echo esc_html($name) ?></a></h3>
				<?php endif ?>
				<?php if ($job !== "") : ?>
					<p class="job"><?php echo esc_html($job) ?></p>
				<?php endif ?>
			</div>
			
			<?php if( $settings['show_popup'] === 'yes' ) : ?>
				<div class="popup_volunteer">
					<?php if( $settings['show_popup'] === 'yes' ) : ?>
						<a class="view_volunteer"><i class="icon_plus"></i></a>
					<?php endif; ?>
					<div class="content_popup">
						<div class="container bgr-popup">
							<span class="btn_close icon_close"></span>
							<div class="row">
								<div class="col-lg-6">
									<div class="volunteer-popup-img">
										<img src="<?php echo esc_attr($settings['image_popup']['url']) ?>" alt="<?php echo esc_attr($settings['name_popup']); ?>">
									</div>
								</div>
								<div class="col-lg-6">
									<div class="volunteer-popup-content">
										<h3 class="second_font"><?php echo esc_html($settings['name_popup']); ?></h3>
										<span class="job"><?php echo esc_html($settings['job_popup']);?></span>
										<p><?php echo esc_html( $settings['content_popup'] );?></p>
										<div class="list-con">
											<ul>
												<?php if (!empty($tabs)) : foreach($tabs as $item) : ?>
													<li><a target="_blank" ref="nofollow" href="<?php echo esc_attr($item['link']['url']) ?>"><i class="<?php echo esc_attr($item['icon']) ?>"></i></a></li>
												<?php endforeach; endif; ?>
											</ul>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			<?php endif;?>
		</div>
		<?php
	}
// end render
}


