<?php
namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class ova_feature extends Widget_Base {

	public function get_name() {
		return 'ova_feature';
	}

	public function get_title() {
		return __( 'Ova Feature', 'ova-framework' );
	}

	public function get_icon() {
		return 'fa fa-id-card-o';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_version',
			[
				'label' => __( 'Version', 'ova-framework' ),
			]
		);

		$this->add_control(
			'version',
			[
				'label'   => __( 'Version', 'ova-framework' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'version_1',
				'options' => [
					'version_1' => __('Version 1', 'ova-framework'),
					'version_2' => __('Version 2', 'ova-framework'),
				],
			]
		);

		$this->end_controls_section();

		// content version 1
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'ova-framework' ),
				'condition' => [
					'version' => 'version_1',
				]
			]
		);

		$this->add_control(
			'type',
			[
				'label'   => __( 'Type', 'ova-framework' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'icon' => __('Icon', 'ova-framework'),
					'image' => __('Image', 'ova-framework'),
				],
			]
		);

		$this->add_control(
			'icon',
			[
				'label'   => __( 'Class Icons', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => 'flaticon-heart-1',
				'condition' => [
					'type' => 'icon',
				]
			]
		);

		

		$this->add_control(
			'image',
			[
				'label'   => __( 'Image', 'ova-framework' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image',
				]
			]
		);

		$this->add_control(
			'show_boxshadow',
			[
				'label' => __( 'Show Box Shadow', 'ova-framework' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'ova-framework' ),
				'label_off' => __( 'Hide', 'ova-framework' ),
				'default' => 'yes',
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_1 .ova-media .wp-media' => 'box-shadow: 3px 0 10px rgba(0, 0, 0, 0.1);',
				],
			]
		);


		$this->add_control(
			'title',
			[
				'label'   => __( 'Title', 'ova-framework' ),
				'type'    => Controls_Manager::TEXTAREA,
				'row'     =>2,
				'default' => __('Our Mission', 'ova-framework'),
			]
		);

		$this->add_control(
			'desc',
			[
				'label'   => __( 'Description', 'ova-framework' ),
				'type'    => Controls_Manager::TEXTAREA,
				'row'     =>5,
				'default' => __('Purus in mollis nunc sed. Lacus suspendisse faucibus.', 'ova-framework'),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __( 'Link', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'ova-framework' ),
				'show_external' => false,
				'default' => [
					'url' => '#',
					
				],
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'ova-framework' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left'    => [
						'title' => __( 'Left', 'ova-framework' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'ova-framework' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'ova-framework' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}}' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// end content version 1

		// content version 2
		$this->start_controls_section(
			'section_content_version_2',
			[
				'label' => __( 'Content', 'ova-framework' ),
				'condition' => [
					'version' => 'version_2',
				]
			]
		);

		$this->add_control(
			'image_version_2',
			[
				'label'   => __( 'Image', 'ova-framework' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'title_version_2',
			[
				'label'   => __( 'Title', 'ova-framework' ),
				'type'    => Controls_Manager::TEXTAREA,
				'row'     => 2,
				'default' => __('Clean Water', 'ova-framework'),
			]
		);

		$this->add_control(
			'desc_version_2',
			[
				'label'   => __( 'Description', 'ova-framework' ),
				'type'    => Controls_Manager::TEXTAREA,
				'row'     =>5,
				'default' => __('Tellus id interdum velit laoreet id donec ultrices tellus orci ac aucto cursus.', 'ova-framework'),
			]
		);

		$this->add_control(
			'text_donate',
			[
				'label'   => __( 'Text Donate', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('DONATE NOW', 'ova-framework'),
			]
		);

		$this->add_control(
			'link_version_2',
			[
				'label' => __( 'Link', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'ova-framework' ),
				'show_external' => false,
				'default' => [
					'url' => '#',
					
				],
			]
		);

		$this->end_controls_section();
		// end content version 2

		//section style box
		$this->start_controls_section(
			'section_box',
			[
				'label' => __( 'Box', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'version' => 'version_2'
				]
			]
		);

		$this->add_control(
			'background_color_box',
			[
				'label' => __( 'Background Color Box', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_2 .wp-ova-feature .ova-media-v2:after' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();



		//section style icon
		$this->start_controls_section(
			'section_icon',
			[
				'label' => __( 'Icon', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'version' => 'version_1'
				]
			]
		);


		$this->add_control(
			'color_icon',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_1 .ova-media .wp-media i:before' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'bg_color_icon',
			[
				'label' => __( 'Background Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_1 .ova-media .wp-media' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_icon_hover',
			[
				'label' => __( 'Color hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_1:hover .ova-media .wp-media i:before' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'bg_color_icon_hover',
			[
				'label' => __( 'Background Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_1:hover .ova-media .wp-media' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_icon',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_1 .ova-media' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style title
		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Title', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .ova-feature .content .title a',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_title',
			[
				'label' => __( 'Color Title', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature .content .title a' => 'color : {{VALUE}};',
					'{{WRAPPER}} .ova-feature.version_2 .wp-ova-feature .ova-media-v2 .content .title:after' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_title_hover',
			[
				'label' => __( 'Color Title Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature .content .title a:hover' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_title',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-feature .content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style description
		$this->start_controls_section(
			'section_desc',
			[
				'label' => __( 'Description', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'desc_typography',
				'selector' => '{{WRAPPER}} .ova-feature .content .desc',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_desc',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature .content .desc' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_desc',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-feature .content .desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style text donate
		$this->start_controls_section(
			'section_donate',
			[
				'label' => __( 'Text Donate', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'version' => 'version_2'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'donate_typography',
				'selector' => '{{WRAPPER}} .ova-feature.version_2 .wp-ova-feature .ova-media-v2 .content .text_donate',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_donate',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_2 .wp-ova-feature .ova-media-v2 .content .text_donate' => 'color : {{VALUE}}; border-color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_donate_hover',
			[
				'label' => __( 'Color Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_2 .wp-ova-feature .ova-media-v2 .content .text_donate:hover' => 'color : {{VALUE}}; border-color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'bg_color_donate_hover',
			[
				'label' => __( 'Background Color Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-feature.version_2 .wp-ova-feature .ova-media-v2 .content .text_donate:hover' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$icon = $settings['icon'];
		$image = $settings['image']['url'];
		$version = $settings['version'];
		?>
		<div class="ova-feature <?php echo esc_attr($version) ?>">
			<?php if($version === 'version_1') : ?>
				<div class="ova-media">
					<div class="wp-media">
						<?php if ($icon !== '') : ?>
							<i class="<?php echo esc_attr($icon); ?>"></i>
						<?php endif ?>

						<?php if (!empty($image)) : ?>
							<img src="<?php echo esc_attr($image) ?>" alt="">
						<?php endif ?>
					</div>
				</div>
				<div class="content">
					<?php if ($settings['title']) : ?>
						<h3 class="title">
							<a href="<?php echo esc_attr($settings['link']['url']) ?>" class="second_font"><?php echo esc_html($settings['title']) ?></a>
						</h3>
					<?php endif ?>
					<?php if($settings['desc']) : ?>
						<p class="desc"><?php echo esc_html($settings['desc']) ?></p>
					<?php endif ?>
				</div>
			<?php endif ?>

			<?php if($version === 'version_2') : ?>
				<div class="wp-ova-feature">
					<div class="ova-media-v2">
						<?php if (!empty($settings['image_version_2']['url'])) : ?>
						<div class="image" style="background-image:url(<?php echo esc_attr($settings['image_version_2']['url']) ?>)">
						</div>
						<?php endif ?>

						<div class="content">
							<?php if ($settings['title_version_2'] !== '') : ?>
								<h3 class="title">
									<a href="<?php echo esc_attr($settings['link_version_2']['url']) ?>" class="second_font"><?php echo esc_html($settings['title_version_2']) ?></a>
								</h3>
							<?php endif ?>

							<?php if ($settings['desc_version_2'] !== '') : ?>
								<p class="desc"><?php echo esc_html($settings['desc_version_2']) ?></p>
							<?php endif ?>

							<?php if ($settings['text_donate'] !== '') : ?>
								<a class="second_font text_donate" href="<?php echo esc_attr($settings['link_version_2']['url']) ?>"><?php echo esc_html($settings['text_donate']) ?></a>
							<?php endif ?>
						</div>
					</div>
				</div>
			<?php endif ?>
		</div>
		<?php
	}
}
