<?php
namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class ova_map_campaign extends Widget_Base {

	public function get_name() {
		return 'ova_map_campaign';
	}

	public function get_title() {
		return __( 'Ova Map Campaign', 'ova-framework' );
	}

	public function get_icon() {
		return 'fa fa-map-o';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		wp_enqueue_script( 'markerclusterer', OVA_PLUGIN_URI.'assets/libs/markerclusterer.js', array('jquery'), false, true );
		wp_enqueue_script( 'scrip-google', "https://maps.googleapis.com/maps/api/js?key=" . get_theme_mod( 'key_google_api', '' ) , array('jquery'), false, true );
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Map', 'ova-framework' ),
			]
		);

		$this->add_control(
			'zoom',
			[
				'label' => __( 'Zoom', 'ova-framework' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 15,
			]
		);

		$this->add_control(
			'image_marker',
			[
				'label' => __( 'Image Marker', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$this->add_control(
			'image_icon',
			[
				'label' => __( 'Image Icon', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$this->add_control(
			'show_zoom',
			[
				'label' => __( 'Zoom Map', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'your-plugin' ),
				'label_off' => __( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);



		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'lat',
			[
				'label'   => __( 'Lat', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => 47.43337,
			]
		);

		$repeater->add_control(
			'lng',
			[
				'label'   => __( 'Lng', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => -72.7824,
			]
		);

		
		$repeater->add_control(
			'text_funed',
			[
				'label'   => __( 'Text Funded', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('Funded', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'number_funed',
			[
				'label'   => __( 'Number Funded', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('42%', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'text_goal',
			[
				'label'   => __( 'Text Goal', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('Goal', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'number_goal',
			[
				'label'   => __( 'Number Goal', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('80000$', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'text_day',
			[
				'label'   => __( 'Text Day', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('Day to go', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'number_day',
			[
				'label'   => __( 'Number Day', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('40', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'class_icon_address',
			[
				'label'   => __( 'Class icon address', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('flaticon-placeholder', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'address',
			[
				'label'   => __( 'Address', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('La Tuque, Canada', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'   => __( 'image', 'ova-framework' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'text_button',
			[
				'label'   => __( 'Text Button', 'ova-framework' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __('DONATE NOW', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __( 'Link', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'ova-framework' ),
				'show_external' => false,
				'default' => [
					'url' => '#',
					
				],
			]
		);


		$this->add_control(
			'tabs',
			[
				'label' => __( 'Tabs', 'ova-framework' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'lat' => __(47.43337, 'ova-framework'),
						'lng' => __(-72.7824, 'ova-framework'),
						'zoom' => __(15, 'ova-framework'),
						'text_funed' => __('Funded', 'ova-framework'),
						'number_funed' => __('42%', 'ova-framework'),
						'text_goal' => __('Goal', 'ova-framework'),
						'number_goal' => __('80,000$', 'ova-framework'),
						'text_day' => __('Day to go', 'ova-framework'),
						'number_day' => __(40, 'ova-framework'),
						'class_icon_address' => __('flaticon-placeholder', 'ova-framework'),
						'address' => __('La Tuque, Canada', 'ova-framework'),
						'text_button' => __('DONATE NOW', 'ova-framework'),
					],

				],
				'title_field' => '{{{ address }}}',
			]
		);


		$this->end_controls_section();

		// end tab section_content


		//section style Number
		$this->start_controls_section(
			'section_number',
			[
				'label' => __( 'Number', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'number_typography',
				'selector' => '{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-text-funded .ova-infl span.number',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_number',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-text-funded .ova-infl span.number' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_number',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-text-funded .ova-infl span.number' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style Text
		$this->start_controls_section(
			'section_text',
			[
				'label' => __( 'Text', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-text-funded .ova-infl span.text',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_text',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-text-funded .ova-infl span.text' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_text',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-text-funded .ova-infl span.text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style Icon address
		$this->start_controls_section(
			'section_icons',
			[
				'label' => __( 'Icon Address', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'width',
			[
				'label' => __( 'Width', 'ova-framework' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 100,
						'step' => 1,
					]
				],

				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-address i:before' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'color_icon',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-address i:before' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_icon',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-address i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style Address
		$this->start_controls_section(
			'section_address',
			[
				'label' => __( 'Address', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'address_typography',
				'selector' => '{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-address .address',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_addree',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-address .address' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin_address',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .wp-content .wp-address .address' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//section style Image
		$this->start_controls_section(
			'section_image',
			[
				'label' => __( 'Image', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'color_image',
			[
				'label' => __( 'Background overlay', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .ova-media:after' => 'background-color : {{VALUE}};',
				],
			]
		);


		$this->end_controls_section();


		//section style Button
		$this->start_controls_section(
			'section_button',
			[
				'label' => __( 'Button', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'buttons_typography',
				'selector' => '{{WRAPPER}} .ova-map-campaign .ova-box .ova-media .text-button',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_button',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .ova-media .text-button' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'bg_color_button',
			[
				'label' => __( 'Background Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .ova-media .text-button' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_button_hover',
			[
				'label' => __( 'Color hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .ova-media .text-button:hover' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'bg_color_button_hover',
			[
				'label' => __( 'Background Color Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-map-campaign .ova-box .ova-media .text-button:hover' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();


	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$address_data = $settings['tabs'];

		$attr_map['zoom_map'] = $settings['zoom'];
		$attr_map['image_icon'] = $settings['image_icon']['url'];
		$attr_map['image_marker'] = $settings['image_marker']['url'];
		$attr_map['show_zoom'] = $settings['show_zoom'];

		?>
		<div class="ova-map-campaign" date-img-con="<?php echo esc_attr($image_icon) ?>" data-marker="<?php echo esc_attr($image_marker) ?>" data-zoom="<?php echo esc_attr($settings['zoom']) ?>">
			<div id="ova-map"></div>
		</div>
		<?php
		wp_localize_script( 'script-elementor', 'address_data', json_encode( $address_data ) );
		wp_localize_script( 'script-elementor', 'attr_map', json_encode( $attr_map ) );

		?>
		
		<?php
	}
}
